Crate deno_http

Crate deno_http 

Modules

compressible

Structs

DefaultHttpPropertyExtractor
HttpConnectionProperties
HttpListenProperties
HttpRequestProperties
HttpStreamReadResource
HttpStreamWriteResource
LocalExecutor
Options
UpgradeUnavailableError
deno_http
An extension for use with the Deno JS runtime. To use it, provide it as an argument when instantiating your runtime:

Enums

HttpConnError
HttpError
HttpNextError
HttpRequestReader
The read half of an HTTP stream.
HttpSocketAddr

Statics

SERVE_NOTIFIER

Traits

HttpPropertyExtractor
Pluggable trait to determine listen, connection and request properties for embedders that wish to provide alternative routes for incoming HTTP.

Functions

http_create_conn_resource
Creates a new HttpConn resource which uses io as its transport.
op_http_serve_address_override
op_http_serve_default_compression
serving_server_kind
Returns the kind of server that triggered SERVE_NOTIFIER: "deno-serve" for Deno.serve, "node-http" for a node:http or node:https server, "node-http2" for a node:http2 server, or None when unknown.